eqMI.ncp: Obtain noncentrality parameter of a chisquare distribution
Description
Calculate the noncentrality parameter as well as the model missipecification epsilon_t given its lower-tail critical value.
Usage
eqMI.ncp(T, df, N, m, alpha = 0.05)
Arguments
T
A chi-square statistic
df
Degrees of freedom
N
Total sample size of all groups
m
Number of groups
alpha
Significance level. Default at 0.05.
Value
The noncentrality parameter ncp, the minimum tolerable size epsilon_t, and RMSEA_t under equivalence testing.
Details
This function is to compute the noncentrality parameter ncp, the model missipecification epsilon_t, and its corresponding RMSEA_t. With equivalence testing, the model missipecification is also the minimum tolerable size that a researcher needs to tolerate if one wishes to proceed with further restricted tests. The formula from Venables (1975) is used for obtaining the noncentrality parameter of a non-central chi-square distribution given its lower-tail critical value.
References
Yuan, K. H., & Chan, W. (2016). Measurement invariance via multigroup SEM: Issues and solutions with chi-square-difference tests. Psychological methods, 21(3), 405-426.